/*
 *  Java Napster version x.yz (for current version number as well as for
 *  additional information see version.txt)
 *
 *  Previous versions of this program were written by Florian Student
 *  and Michael Ransburg available at www.weblicity.de/jnapster and
 *  http://www.tux.org/~daneel/content/projects/10.shtml respectively.
 *
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
package xnap.plugin.nap.util;

import xnap.plugin.nap.net.Server;
import xnap.util.QuotedStringTokenizer;

import java.io.*;
import java.util.*;

public class ServerFile {

    //--- Data Field(s) ---

    private BufferedReader in = null;
    private BufferedWriter out = null;
    private String filename;

    //--- Constructor(s) ---
	
    public ServerFile(String filename)
    {
	this.filename = filename;
    }

    //--- Method(s) ---

    public void close()
    {
	try {
	    if (in != null) {
		in.close();
	    }
	    if (out != null) {
		out.close();
	    }
	}	    
	catch (IOException e) {
	}
    }

    public String getFilename()
    {
	return filename;
    }
    
    public BufferedReader getIn()
    {
	return in;
    }

    public BufferedWriter getOut()
    {
	return out;
    }

    public void openReader() throws IOException
    {
	in = new BufferedReader(new FileReader(getFilename()));
    }

    public void openWriter() throws IOException
    {
	out = new BufferedWriter(new FileWriter(getFilename(), false));
    }

    public Server readServer() throws IOException {
	String line;

	while ((line = getIn().readLine()) != null) {
	    try {
		QuotedStringTokenizer t = new QuotedStringTokenizer(line, " :");
		
		if (t.countTokens() < 2) {
		    continue;
		}
		    
		String ip = t.nextToken();
		int port = Integer.parseInt(t.nextToken());
		String network = "";
		if (t.countTokens() > 0) {
		    network = t.nextToken();
		}

		Server s = new Server(ip, port, network);

		if (t.countTokens() >= 3) {
		    s.setUsername(t.nextToken());
		}
		if (t.countTokens() > 0) {
		    s.setPassword(t.nextToken());
		}
		if (t.countTokens() > 0) {
		    s.setEmail(t.nextToken());
		}

		return s;
	    } 
	    catch (NumberFormatException e) {
	    }
	}

        return null;
    }

    public void writeServer(Server s) throws IOException
    {
	StringBuffer sb = new StringBuffer();
	sb.append(s.getHost());
	sb.append(":");
	sb.append(s.getPort());
	sb.append(" ");
	sb.append(s.getNetwork().length() > 0 ? s.getNetwork() : "\"\"");
	if (s.isLoginCustomized()) {
	    sb.append(" ");
	    sb.append(s.getUsername());
	    sb.append(" ");
	    sb.append(s.getPassword());
	    sb.append(" ");
	    sb.append(s.getEmail());
	}
	out.write(sb.toString());
	out.newLine();
    }

}
